==> zorp_2.0.9.orig.tar.gz: zorp-2.0.9/pylib/Zorp/Addon.py <==
class AIMProxy(PlugProxy):
	pass

class CompuserveProxy(PlugProxy):
	pass

class CVSProxy(PlugProxy):
	pass

class GopherProxy(PlugProxy):
	pass

class GroupwiseClientProxy(PlugProxy):
	pass

class GroupwiseServerProxy(PlugProxy):
	pass

class HttpRegexpURIFilterProxy(HttpProxyURIFilter):
	matcher=RegexpFileMatcher("/etc/zorp/blacklist-http", "/etc/zorp/blacklist-http.ignore")

class NontransHttpRegexURIFilterProxy(HttpProxyURIFilter):
	matcher=RegexpFileMatcher("/etc/zorp/blacklist-http", "/etc/zorp/blacklist-http.ignore")

	def config(self):
		HttpProxyURIFilter.config(self)
		self.transparent_mode=FALSE

class HttpWebdavProxy(HttpProxy):
	def config(self):
		HttpProxy.config(self)
		self.request["PROPFIND"] = (HTTP_REQ_ACCEPT)
		self.request["PROPPATCH"] = (HTTP_REQ_ACCEPT)
		self.request["MKCOL"] = (HTTP_REQ_ACCEPT)
		self.request["COPY"] = (HTTP_REQ_ACCEPT)
		self.request["MOVE"] = (HTTP_REQ_ACCEPT)
		self.request["LOCK"] = (HTTP_REQ_ACCEPT)
		self.request["UNLOCK"] = (HTTP_REQ_ACCEPT)

class NontransHttpWebdavProxy(HttpProxy):
	def config(self):
		HttpProxy.config(self)
		self.request["PROPFIND"] = (HTTP_REQ_ACCEPT)
		self.request["PROPPATCH"] = (HTTP_REQ_ACCEPT)
		self.request["MKCOL"] = (HTTP_REQ_ACCEPT)
		self.request["COPY"] = (HTTP_REQ_ACCEPT)
		self.request["MOVE"] = (HTTP_REQ_ACCEPT)
		self.request["LOCK"] = (HTTP_REQ_ACCEPT)
		self.request["UNLOCK"] = (HTTP_REQ_ACCEPT)

class HttpsPlug(PlugProxy):
	pass

class ICQProxy(PlugProxy):
	pass

class IrcProxy(PlugProxy):
	pass

class LdapsProxyPlug(PlugProxy):
	pass

class NNTPsProxy(PlugProxy):
	pass

class LotusNotesProxy(PlugProxy):
	pass

class Pop3sPlugProxy(PlugProxy):
	pass

class RTSPProxy(PlugProxy):
	pass

class ShoutCastProxy(PlugProxy):
	pass

class NetbiosSSNProxy(PlugProxy):
	pass

class PgsqlProxy(PlugProxy):
	pass

class OraPlugProxy(PlugProxy):
	pass

class MSSQLProxy(PlugProxy):
	pass

class SSHProxy(PlugProxy):
	pass

==> zorp_3.0.8-0.3.tar.gz: zorp-3.0.8/pylib/Zorp/Addon.py <==
class AIMProxy(PlugProxy):
	pass

class CompuserveProxy(PlugProxy):
	pass

class CVSProxy(PlugProxy):
	pass

class GopherProxy(PlugProxy):
	pass

class GroupwiseClientProxy(PlugProxy):
	pass

class GroupwiseServerProxy(PlugProxy):
	pass

class HttpRegexpURIFilterProxy(HttpProxyURIFilter):
	matcher=RegexpFileMatcher("/etc/zorp/blacklist-http", "/etc/zorp/blacklist-http.ignore")

class NontransHttpRegexURIFilterProxy(HttpProxyURIFilter):
	matcher=RegexpFileMatcher("/etc/zorp/blacklist-http", "/etc/zorp/blacklist-http.ignore")

	def config(self):
		HttpProxyURIFilter.config(self)
		self.transparent_mode=FALSE

class HttpWebdavProxy(HttpProxy):
	def config(self):
		HttpProxy.config(self)
		self.request["PROPFIND"] = (HTTP_REQ_ACCEPT)
		self.request["PROPPATCH"] = (HTTP_REQ_ACCEPT)
		self.request["MKCOL"] = (HTTP_REQ_ACCEPT)
		self.request["COPY"] = (HTTP_REQ_ACCEPT)
		self.request["MOVE"] = (HTTP_REQ_ACCEPT)
		self.request["LOCK"] = (HTTP_REQ_ACCEPT)
		self.request["UNLOCK"] = (HTTP_REQ_ACCEPT)

class NontransHttpWebdavProxy(HttpProxyNonTransparent):
	def config(self):
		HttpProxyNonTransparent.config(self)
		self.request["PROPFIND"] = (HTTP_REQ_ACCEPT)
		self.request["PROPPATCH"] = (HTTP_REQ_ACCEPT)
		self.request["MKCOL"] = (HTTP_REQ_ACCEPT)
		self.request["COPY"] = (HTTP_REQ_ACCEPT)
		self.request["MOVE"] = (HTTP_REQ_ACCEPT)
		self.request["LOCK"] = (HTTP_REQ_ACCEPT)
		self.request["UNLOCK"] = (HTTP_REQ_ACCEPT)

class HttpsPlug(PlugProxy):
	pass

class ICQProxy(PlugProxy):
	pass

class IrcProxy(PlugProxy):
	pass

class LdapsProxyPlug(PlugProxy):
	pass

class NNTPsProxy(PlugProxy):
	pass

class LotusNotesProxy(PlugProxy):
	pass

class Pop3sPlugProxy(PlugProxy):
	pass

class RTSPProxy(PlugProxy):
	pass

class ShoutCastProxy(PlugProxy):
	pass

class NetbiosSSNProxy(PlugProxy):
	pass

class PgsqlProxy(PlugProxy):
	pass

class OraPlugProxy(PlugProxy):
	pass

class MSSQLProxy(PlugProxy):
	pass

class SSHProxy(PlugProxy):
	pass
